==> deepin-update-ui_1.0.12.tar.xz: BUILD/src/dde-abrecovery/translations/dde-rollback_hu.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hu">
<context>
    <name>BackgroundWidget</name>
    <message>
        <source>Rolling back the system, please wait...</source>
        <translation>A rendszer visszaállítása folyamatban, kérjük várjon...</translation>
    </message>
</context>
<context>
    <name>RecoveryWidget</name>
    <message>
        <source>Rollback failed.</source>
        <translation>A visszaállítás nem sikerült.</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Újraindítás</translation>
    </message>
    <message>
        <source>Updates failed.</source>
        <translation>A frissítés sikertelen.</translation>
    </message>
    <message>
        <source>Updates failed: it was interrupted.</source>
        <translation>Sikertelen frissítés: a folyamat megszakadt</translation>
    </message>
    <message>
        <source>Updates failed: DPKG error.</source>
        <translation>Sikertelen frissítés: DPKG hiba.</translation>
    </message>
    <message>
        <source>Updates failed: insufficient disk space.</source>
        <translation>Sikertelen frissítés: nincs elegendő lemezterület</translation>
    </message>
    <message>
        <source>Are you sure you want to roll back to %1 backed up on %2?</source>
        <translation>Biztosan vissza szeretne állni a %1 verzióra, mely a %2 hordozón található?</translation>
    </message>
    <message>
        <source>Cancel and Reboot</source>
        <translation>Mégsem és Újraindítás</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Megerősítés</translation>
    </message>
</context>
</TS>

==> deepin-update-ui_1.0.35.tar.xz: BUILD/src/dde-abrecovery/translations/dde-rollback_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>BackgroundWidget</name>
    <message>
        <source>Rolling back the system, please wait...</source>
        <translation>A rendszer visszaállítása folyamatban, kérjük várjon...</translation>
    </message>
</context>
<context>
    <name>RecoveryWidget</name>
    <message>
        <source>Rollback failed.</source>
        <translation>A visszaállítás nem sikerült.</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Újraindítás</translation>
    </message>
    <message>
        <source>Updates failed.</source>
        <translation>A frissítés sikertelen.</translation>
    </message>
    <message>
        <source>Updates failed: it was interrupted.</source>
        <translation>Sikertelen frissítés: a folyamat megszakadt</translation>
    </message>
    <message>
        <source>Updates failed: DPKG error.</source>
        <translation>Sikertelen frissítés: DPKG hiba.</translation>
    </message>
    <message>
        <source>Updates failed: insufficient disk space.</source>
        <translation>Sikertelen frissítés: nincs elegendő lemezterület</translation>
    </message>
    <message>
        <source>Are you sure you want to roll back to %1 backed up on %2?</source>
        <translation>Biztosan vissza szeretne állni a %1 verzióra, mely a %2 hordozón található?</translation>
    </message>
    <message>
        <source>Cancel and Reboot</source>
        <translation>Mégsem és Újraindítás</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Megerősítés</translation>
    </message>
</context>
</TS>
